Examples
========

End-to-end workflows are shown in the :doc:`Demonstrator <../demonstrator/index>` page.

Tutorials for the individual packages
-------------------------------------

Further examples for the individual packages are available in these tutorials:

.. toctree::
   :maxdepth: 2

   mammos-analysis/index
   mammos-dft/index
   mammos-entity/index
   mammos-mumag/index
   mammos-spindynamics/index
   mammos-units/index


.. include:: /downloading-examples.rst
